@@ -63,27 +63,31 @@ extern "C" {
 #include <gmime/gmime-filter-best.h>
 #include <gmime/gmime-filter-charset.h>
 #include <gmime/gmime-filter-crlf.h>
+#include <gmime/gmime-filter-enriched.h>
 #include <gmime/gmime-filter-from.h>
+#include <gmime/gmime-filter-gzip.h>
 #include <gmime/gmime-filter-html.h>
 #include <gmime/gmime-filter-md5.h>
 #include <gmime/gmime-filter-strip.h>
+#include <gmime/gmime-filter-windows.h>
 #include <gmime/gmime-filter-yenc.h>
 #include <gmime/gmime-session.h>
+#include <gmime/gmime-session-simple.h>
 #include <gmime/gmime-cipher-context.h>
 #include <gmime/gmime-gpg-context.h>
 
 /* GMIME version */
 static const guint gmime_major_version = 2;
-static const guint gmime_minor_version = 0;
-static const guint gmime_micro_version = 14;
+static const guint gmime_minor_version = 2;
+static const guint gmime_micro_version = 1;
 static const guint gmime_interface_age = 0;
 static const guint gmime_binary_age    = 0;
 
 #define GMIME_CHECK_VERSION(major,minor,micro)    \
-    (gmime_major_version > (major) || \
-     (gmime_major_version == (major) && gmime_minor_version > (minor)) || \
-     (gmime_major_version == (major) && gmime_minor_version == (minor) && \
-      gmime_micro_version >= (micro)))
+    (2 > (major) || \
+     (2 == (major) && 2 > (minor)) || \
+     (2 == (major) && 2 == (minor) && \
+      1 >= (micro)))
 
 
 /**
@@ -98,6 +102,7 @@ static const guint gmime_binary_age    = 0;
 #define GMIME_INIT_FLAG_UTF8  (1 << 0)
 
 void g_mime_init (guint32 flags);
+void g_mime_shutdown (void);
 
 #ifdef __cplusplus
 }
