@@ -257,6 +257,67 @@ internet_address_add_member (InternetAddress *ia, InternetAddress *member)
 }
 
 
+/**
+ * internet_address_get_type:
+ * @ia: internet address
+ *
+ * Returns the type of the internet address.
+ **/
+InternetAddressType
+internet_address_get_type (InternetAddress *ia)
+{
+	g_return_val_if_fail (ia != NULL, INTERNET_ADDRESS_NONE);
+
+	return ia->type;
+}
+
+/**
+ * internet_address_get_name:
+ * @ia: internet address
+ *
+ * Returns the name of the internet address.
+ **/
+const char *
+internet_address_get_name (InternetAddress *ia)
+{
+	g_return_val_if_fail (ia != NULL, NULL);
+
+	return ia->name;
+}
+
+
+/**
+ * internet_address_get_addr:
+ * @ia: internet address
+ *
+ * Returns the address of the internet address.
+ **/
+const char *
+internet_address_get_addr (InternetAddress *ia)
+{
+	g_return_val_if_fail (ia != NULL, NULL);
+	g_return_val_if_fail (ia->type != INTERNET_ADDRESS_GROUP, NULL);
+
+	return ia->value.addr;
+}
+
+
+/**
+ * internet_address_get_members:
+ * @ia: internet address
+ *
+ * Returns the list of internet addresses
+ **/
+const InternetAddressList *
+internet_address_get_members (InternetAddress *ia)
+{
+	g_return_val_if_fail (ia != NULL, NULL);
+	g_return_val_if_fail (ia->type != INTERNET_ADDRESS_NAME, NULL);
+
+	return ia->value.members;
+}
+
+
 /**
  * internet_address_list_prepend:
  * @list: a list of internet addresses
@@ -365,17 +426,17 @@ internet_address_list_concat (InternetAddressList *a, InternetAddressList *b)
  * internet_address_list_next:
  * @list: list of internet addresses
  *
- * Returns the following node in @list.
+ * Advances to the next address node in the InternetAddessList.
+ *
+ * Returns the next address node in the InternetAddessList.
  **/
 InternetAddressList *
 internet_address_list_next (const InternetAddressList *list)
 {
-	if (!list)
-		return NULL;
-
-	return list->next;
+	return list ? list->next : NULL;
 }
 
+
 /**
  * internet_address_list_get_address:
  * @list: list of internet addresses
